#######
History
#######

.. |dob| replace:: ``dob``
.. _dob: https://github.com/tallybark/dob

.. |dob-bright| replace:: ``dob-bright``
.. _dob-bright: https://github.com/tallybark/dob-bright

.. |dob-prompt| replace:: ``dob-prompt``
.. _dob-prompt: https://github.com/tallybark/dob-prompt

.. :changelog:

1.1.3 (2020-06-29)
==================

- Change ownership to https://github.com/tallybark.

1.1.2 (2020-06-18)
==================

- Packaging: Update dependency versions to pickup library changes.

1.1.1 (2020-06-18)
==================

- Packaging: Update dependencies.

- Update: General refactoring and updates per changes to other packages.

1.1.0 (2020-04-26)
==================

- Packaging: Update dependency versions to pickup library changes.

1.0.5 (2020-04-12)
==================

- Bugfix: Prompt crashes if user presses Ctrl-D on empty text.

- Bugfix: Prompt not positioned correctly after Escape keypress.

- Enhance: Reset chosen completer on Ctrl-C (e.g., like pressing ``F2``).

1.0.4 (2020-04-08)
==================

- Bugfix: Choosing prompt completion fails (because upstream PTK changes).

1.0.3 (2020-04-01)
==================

- Bugfix: Send package name to get_version, lest nark use its own.

1.0.2 (2020-04-01)
==================

- Refactor: DRY: Use new library get_version.

1.0.0 (2020-03-30)
==================

- Booyeah: Inaugural release (spin-off from |dob|_).

